"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const rest_1 = require("../../../rest");
const ProvisioningValidator_1 = require("./ProvisioningValidator");
const ProvisioningConstants_1 = require("./ProvisioningConstants");
/**
 * Get variables of the provisioned instance.
 * @export
 * @class ListInstanceVariables
 */
class ListInstanceVariables {
    /**
     * This operation returns variables of the provisioned instance.
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {string} zOSMFVersion - the URI path that identifies the version of the provisioning service.
     * @param {string} instanceId - unique id of the provisioned instance .
     * @returns {Promise<IProvisionedInstanceVariable>} z/OSMF response object, @see {IProvisionedInstanceVariable}
     * @memberof ListInstanceVariables
     */
    static listVariablesCommon(session, zOSMFVersion, instanceId) {
        return __awaiter(this, void 0, void 0, function* () {
            ProvisioningValidator_1.ProvisioningValidator.validateSession(session);
            ProvisioningValidator_1.ProvisioningValidator.validateNotEmptyString(zOSMFVersion, ProvisioningConstants_1.nozOSMFVersion.message);
            ProvisioningValidator_1.ProvisioningValidator.validateNotEmptyString(instanceId, ProvisioningConstants_1.noInstanceId.message);
            const resourcesQuery = this.getResourcesQuery(zOSMFVersion, instanceId);
            return rest_1.ZosmfRestClient.getExpectJSON(session, resourcesQuery);
        });
    }
    /**
     * Builds a resources query from passed parameters which is needed for z/OSMF api URI.
     * @param {string} zOSMFVersion - the URI path that identifies the version of the provisioning service.
     * @param {string} instanceId - unique id of the provisioned instance .
     * @returns {string} URI path for the REST call.
     * @memberof ListInstanceVariables
     */
    static getResourcesQuery(zOSMFVersion, instanceId) {
        let resourcesQuery = `${ProvisioningConstants_1.ProvisioningConstants.RESOURCE}/${zOSMFVersion}/`;
        resourcesQuery += `${ProvisioningConstants_1.ProvisioningConstants.INSTANCES_RESOURCE}/${instanceId}/`;
        resourcesQuery += `${ProvisioningConstants_1.ProvisioningConstants.VARIABLES_RESOURCE}`;
        return resourcesQuery;
    }
}
exports.ListInstanceVariables = ListInstanceVariables;
//# sourceMappingURL=ListInstanceVariables.js.map