"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const rest_1 = require("../../../rest");
const WorkflowConstants_1 = require("./WorkflowConstants");
const WorkflowValidator_1 = require("./WorkflowValidator");
class DefinitionWorkflow {
    /**
     * This operation returns properties of the workflow.
     * Parameters indicators are mandatory,request can include steps and variables indicator for requested result.
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {string} filePath - workflow definition name with path.
     * @param {string} zOSMFVersion - the URI path that identifies the version of the provisioning service.
     * @param {boolean} steps - Optional parameter for listing steps properties.
     * @param {boolean} variables - Optional parameter for listing variables properties.
     * @returns {Promise<IWorkflowDefinition>} z/OSMF response object
     * @memberof Definition
     */
    // main method
    static getWorkflowDefinition(session, zOSMFVersion = WorkflowConstants_1.WorkflowConstants.ZOSMF_VERSION, filePath, steps, variables) {
        return __awaiter(this, void 0, void 0, function* () {
            WorkflowValidator_1.WorkflowValidator.validateSession(session);
            WorkflowValidator_1.WorkflowValidator.validateNotEmptyString(zOSMFVersion, WorkflowConstants_1.nozOSMFVersion.message);
            let wfPath;
            WorkflowValidator_1.WorkflowValidator.validateNotEmptyString(filePath, WorkflowConstants_1.noWorkflowDefinitionFile.message);
            wfPath = filePath;
            let resourcesQuery = `${WorkflowConstants_1.WorkflowConstants.RESOURCE}/${zOSMFVersion}/`;
            resourcesQuery += `${WorkflowConstants_1.WorkflowConstants.WORKFLOW_DEFINITION}?${WorkflowConstants_1.WorkflowConstants.filePath}=${wfPath}`;
            if (steps && variables) {
                resourcesQuery += `&${WorkflowConstants_1.WorkflowConstants.returnData}=${WorkflowConstants_1.WorkflowConstants.steps},${WorkflowConstants_1.WorkflowConstants.variables}`;
            }
            else if (steps) {
                resourcesQuery += `&${WorkflowConstants_1.WorkflowConstants.returnData}=${WorkflowConstants_1.WorkflowConstants.steps}`;
            }
            else if (variables) {
                resourcesQuery += `&${WorkflowConstants_1.WorkflowConstants.returnData}=${WorkflowConstants_1.WorkflowConstants.variables}`;
            }
            return rest_1.ZosmfRestClient.getExpectJSON(session, resourcesQuery, [imperative_1.Headers.APPLICATION_JSON]);
        });
    }
}
exports.DefinitionWorkflow = DefinitionWorkflow;
//# sourceMappingURL=Definition.js.map