"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const upload_1 = require("../../../api/methods/upload");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
const utils_1 = require("../../../../../utils");
/**
 * Handler to stream data from stdin to a data set
 * @export
 */
class StdinToDataSetHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = yield utils_1.readStdin();
            const result = yield upload_1.Upload.bufferToDataSet(session, Buffer.from(payload), commandParameters.arguments.dataSetName, {
                volume: commandParameters.arguments.volumeSerial,
                binary: commandParameters.arguments.binary
            });
            if (result.success) {
                const formatMessage = imperative_1.TextUtils.prettyJson({
                    success: result.success,
                    from: "stdin",
                    to: commandParameters.arguments.dataSetName
                });
                commandParameters.response.console.log(formatMessage);
            }
            return result;
        });
    }
}
exports.default = StdinToDataSetHandler;
//# sourceMappingURL=StdinToDataSet.handler.js.map