import { AbstractSession } from "@brightside/imperative";
import { IJob } from "./doc/response/IJob";
import { ICancelJobParms } from "./doc/input/ICancelJobParms";
/**
 * Class to handle deletion of job information
 * @export
 * @class CancelJobs
 */
export declare class CancelJobs {
    /**
     * Cancel and purge a job
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {string} jobname - job name to be translated into parms object
     * @param {string} jobid - job id to be translated into parms object
     * @returns {Promise<void>} - promise that resolves when the API call is complete
     * @memberof CancelJobs
     */
    static cancelJob(session: AbstractSession, jobname: string, jobid: string, version?: string): Promise<void>;
    /**
     * Cancel and purge a job
     * Alternative version of the cancel API accepting an IJob object returned from other APIs such as GetJobs and SubmitJobs
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {IJob} job - the job that you want to cancel
     * @param {string} version - version of cancel request
     * @returns {Promise<void>} -  promise that resolves when the API call is complete
     * @memberof CancelJobs
     */
    static cancelJobForJob(session: AbstractSession, job: IJob, version?: string): Promise<void>;
    /**
     * Cancel and purge a job
     * Full version of the API with a parameter object
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {ICancelJobParms} parms - parm object (see ICancelJobParms interface for details)
     * @returns {Promise<void>} - promise that resolves when the API call is complete
     * @memberof CancelJobs
     */
    static cancelJobCommon(session: AbstractSession, parms: ICancelJobParms): Promise<void>;
    /**
     * Getter for brightside logger
     * @returns {Logger}
     */
    private static readonly log;
}
