/**
 * This enum represents the possible results from isGuiAvailable.
 */
export declare enum GuiResult {
    /** A GUI is available */
    GUI_AVAILABLE = 0,
    /** No GUI because this is an SSH connection. */
    NO_GUI_SSH = 1,
    /** No GUI because The $DISPLAY environment variable is not set. */
    NO_GUI_NO_DISPLAY = 2
}
/**
 * A collection of utilities related to the running process.
 * @export
 * @class ProcessUtils
 */
export declare class ProcessUtils {
    /**
     * Process utility to wrap callback process routines into promises
     * Turn nextTick into a promise to prevent nesting
     * @static
     * @param {() => void} callback - called before promise is resolved
     * @param {...any[]} args - arguments passed to the callback
     * @returns {Promise<void>} - fullfilled whenever callback is invoked
     * @memberof ProcessUtils
     */
    static nextTick(callback: (...args: any[]) => void, ...args: any[]): Promise<void>;
    /**
     * Is a Graphical User Interface avaiable in the environment in which
     * the current command is running?
     *
     * @returns {boolean} - True if GUI. False when no GUI.
     */
    static isGuiAvailable(): GuiResult;
}
