"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const zowe = require("@brightside/core");
// tslint:disable: max-classes-per-file
/**
 * An implementation of the Zowe Explorer API Common interface for zOSMF.
 */
class ZosmfApiCommon {
    constructor(profile) {
        this.profile = profile;
    }
    static getProfileTypeName() {
        return "zosmf";
    }
    getProfileTypeName() {
        return ZosmfUssApi.getProfileTypeName();
    }
    getSession(profile) {
        if (!this.session) {
            this.session = zowe.ZosmfSession.createBasicZosmfSession((profile || this.profile).profile);
        }
        return this.session;
    }
}
/**
 * An implementation of the Zowe Explorer USS API interface for zOSMF.
 */
class ZosmfUssApi extends ZosmfApiCommon {
    fileList(ussFilePath) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.List.fileList(this.getSession(), ussFilePath);
        });
    }
    isFileTagBinOrAscii(ussFilePath) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Utilities.isFileTagBinOrAscii(this.getSession(), ussFilePath);
        });
    }
    getContents(inputFilePath, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Download.ussFile(this.getSession(), inputFilePath, options);
        });
    }
    putContents(inputFilePath, ussFilePath, binary, localEncoding, etag, returnEtag) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Upload.fileToUSSFile(this.getSession(), inputFilePath, ussFilePath, binary, localEncoding, etag, returnEtag);
        });
    }
    uploadDirectory(inputDirectoryPath, ussDirectoryPath, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Upload.dirToUSSDirRecursive(this.getSession(), inputDirectoryPath, ussDirectoryPath, options);
        });
    }
    create(ussPath, type, mode) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Create.uss(this.getSession(), ussPath, type);
        });
    }
    delete(ussPath, recursive) {
        return __awaiter(this, void 0, void 0, function* () {
            // handle zosmf api issue with file paths
            const fixedName = ussPath.startsWith("/") ? ussPath.substring(1) : ussPath;
            return zowe.Delete.ussFile(this.getSession(), fixedName, recursive);
        });
    }
    rename(currentUssPath, newUssPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield zowe.Utilities.renameUSSFile(this.getSession(), currentUssPath, newUssPath);
            return {
                success: true,
                commandResponse: null,
                apiResponse: result
            };
        });
    }
}
exports.ZosmfUssApi = ZosmfUssApi;
/**
 * An implementation of the Zowe Explorer MVS API interface for zOSMF.
 */
class ZosmfMvsApi extends ZosmfApiCommon {
    dataSet(filter, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.List.dataSet(this.getSession(), filter, options);
        });
    }
    allMembers(dataSetName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.List.allMembers(this.getSession(), dataSetName, options);
        });
    }
    getContents(dataSetName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Download.dataSet(this.getSession(), dataSetName, options);
        });
    }
    putContents(inputFilePath, dataSetName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Upload.pathToDataSet(this.getSession(), inputFilePath, dataSetName, options);
        });
    }
    createDataSet(dataSetType, dataSetName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Create.dataSet(this.getSession(), dataSetType, dataSetName, options);
        });
    }
    createDataSetMember(dataSetName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Upload.bufferToDataSet(this.getSession(), Buffer.from(""), dataSetName, options);
        });
    }
    copyDataSetMember({ dataSetName: fromDataSetName, memberName: fromMemberName }, { dataSetName: toDataSetName, memberName: toMemberName }, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Copy.dataSet(this.getSession(), { dataSetName: fromDataSetName, memberName: fromMemberName }, { dataSetName: toDataSetName, memberName: toMemberName }, options);
        });
    }
    renameDataSet(currentDataSetName, newDataSetName) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Rename.dataSet(this.getSession(), currentDataSetName, newDataSetName);
        });
    }
    renameDataSetMember(currentMemberName, newMemberName, afterMemberName) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Rename.dataSetMember(this.getSession(), currentMemberName, newMemberName, afterMemberName);
        });
    }
    deleteDataSet(dataSetName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return zowe.Delete.dataSet(this.getSession(), dataSetName);
        });
    }
}
exports.ZosmfMvsApi = ZosmfMvsApi;
/**
 * An implementation of the Zowe Explorer JES API interface for zOSMF.
 */
class ZosmfJesApi extends ZosmfApiCommon {
    getJobsByOwnerAndPrefix(owner, prefix) {
        return zowe.GetJobs.getJobsByOwnerAndPrefix(this.getSession(), owner, prefix);
    }
    getJob(jobid) {
        return zowe.GetJobs.getJob(this.getSession(), jobid);
    }
    getSpoolFiles(jobname, jobid) {
        return zowe.GetJobs.getSpoolFiles(this.getSession(), jobname, jobid);
    }
    downloadSpoolContent(parms) {
        return zowe.DownloadJobs.downloadAllSpoolContentCommon(this.getSession(), parms);
    }
    getSpoolContentById(jobname, jobid, spoolId) {
        return zowe.GetJobs.getSpoolContentById(this.getSession(), jobname, jobid, spoolId);
    }
    getJclForJob(job) {
        return zowe.GetJobs.getJclForJob(this.getSession(), job);
    }
    submitJcl(jcl, internalReaderRecfm, internalReaderLrecl) {
        return zowe.SubmitJobs.submitJcl(this.getSession(), internalReaderRecfm, internalReaderLrecl);
    }
    submitJob(jobDataSet) {
        return zowe.SubmitJobs.submitJob(this.getSession(), jobDataSet);
    }
    deleteJob(jobname, jobid) {
        return zowe.DeleteJobs.deleteJob(this.getSession(), jobname, jobid);
    }
}
exports.ZosmfJesApi = ZosmfJesApi;

//# sourceMappingURL=ZoweExplorerZosmfApi.js.map
