"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const utils = require("../utils");
const extension = require("../../src/extension");
const ZoweExplorerApiRegister_1 = require("../api/ZoweExplorerApiRegister");
function uploadDialog(node, datasetProvider) {
    return __awaiter(this, void 0, void 0, function* () {
        const fileOpenOptions = {
            canSelectFiles: true,
            openLabel: "Upload File",
            canSelectMany: true
        };
        const value = yield vscode.window.showOpenDialog(fileOpenOptions);
        yield Promise.all(value.map((item) => __awaiter(this, void 0, void 0, function* () {
            // Convert to vscode.TextDocument
            const doc = yield vscode.workspace.openTextDocument(item);
            yield uploadFile(node, doc);
        })));
        datasetProvider.refresh();
    });
}
exports.uploadDialog = uploadDialog;
function getDatasetLabel(node) {
    if (node.mParent && node.mParent.contextValue === extension.FAVORITE_CONTEXT) {
        const profileEnd = "]: ";
        const profileIndex = node.label.indexOf(profileEnd);
        return node.label.substr(profileIndex + profileEnd.length, node.label.length);
    }
    return node.label;
}
exports.getDatasetLabel = getDatasetLabel;
function uploadFile(node, doc) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const datasetName = getDatasetLabel(node);
            yield ZoweExplorerApiRegister_1.ZoweExplorerApiRegister.getMvsApi(node.profile).putContents(doc.fileName, datasetName);
        }
        catch (e) {
            yield utils.errorHandling(e, node.getProfileName(), e.message);
        }
    });
}
exports.uploadFile = uploadFile;

//# sourceMappingURL=mvsNodeActions.js.map
